@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,8 +19,7 @@
 #define FILTERBALSA_H
 
 #include "filters.h"
-namespace MailImporter
-{
+namespace MailImporter {
 class FilterBalsaPrivate;
 class MAILIMPORTER_EXPORT FilterBalsa : public Filter
 {
@@ -28,9 +27,10 @@ public:
     FilterBalsa();
     ~FilterBalsa();
 
-    void import() Q_DECL_OVERRIDE;
+    void import() override;
     void importMails(const QString &maildir);
     static QString defaultSettingsPath();
+    static QString isMailerFound();
     QString localMailDirPath();
 private:
     void importDirContents(const QString &);
